// This file is part of the Acts project.
//
// Copyright (C) 2020 CERN for the benefit of the Acts project
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

#pragma once

namespace ActsFatras {

/// Single particle simulation result (and intermediate state).
///
/// This result struct is used by multiple components and thus defined
/// separately.
struct SimulationResult {
  /// Current/ final particle state.
  Particle particle;
  /// Material accumulated during the propagation.
  /// The initial particle can already have some accumulated material. The
  /// particle stores the full material path. This keeps track of the
  /// additional material accumulated during simulation.
  Particle::Scalar pathInX0 = 0;
  Particle::Scalar pathInL0 = 0;
  /// Whether the particle is alive or not, i.e. could be simulated further.
  bool isAlive = true;
  /// Additional particles generated by interactions.
  std::vector<Particle> generatedParticles;
  /// Hits created by the particle.
  std::vector<Hit> hits;
};

}  // namespace ActsFatras
